@@ -4,7 +4,7 @@ import json
 
 from fanstatic import Library
 from fanstatic import Resource
-from js.tinymce import tinymce
+from js.deform import resource_mapping
 from kotti.resources import Content
 from kotti.resources import File
 from kotti.resources import Image
@@ -17,6 +17,11 @@ from pyramid.view import view_defaults
 
 library = Library('kotti_tinymce', 'static')
 
+tinymce = Resource(
+    library,
+    "tinymce.js",
+    minified="tinymce.min.js"
+)
 kotti_tinymce = Resource(
     library,
     "kotti_tinymce.js",
@@ -91,6 +96,11 @@ class KottiTinyMCE():
 
         kotti_tinymce.need()
 
+        if self.request.session["kottibrowser_requested_type"] == "image":
+            upload_allowed = Image.type_info.addable(self.context, self.request)
+        else:
+            upload_allowed = File.type_info.addable(self.context, self.request)
+
         return {
             "image_selectable":
             self.context.type ==
@@ -102,8 +112,7 @@ class KottiTinyMCE():
             "image_url":
             self.request.resource_url(self.context) + 'image/span1',
 
-            # TODO: upload_allowed needs a better check.
-            "upload_allowed": self.context.type == 'document',
+            "upload_allowed": upload_allowed,
         }
 
     @view_config(name="kottibrowser",
@@ -158,22 +167,16 @@ class KottiTinyMCE():
 
 
 def kotti_configure(settings):
-    settings['kotti.includes'] += ' kotti_tinymce'
+    settings['pyramid.includes'] += ' kotti_tinymce'
     settings['pyramid_deform.template_search_path'] = (
         'kotti_tinymce:templates/deform ' +
         settings['pyramid_deform.template_search_path'])
 
 
 def includeme(config):
+
     config.scan("kotti_tinymce")
     config.add_translation_dirs('kotti_tinymce:locale/')
-    try:
-        # kotti >= 0.8
-        from js.deform import resource_mapping
-        edit_needed = resource_mapping['tinymce'].append(kotti_tinymce)
-        resource_mapping['tinymce'].append(kottiimage_plugin)
-        resource_mapping['tinymce'].append(codemirror_plugin)
-    except ImportError:  # pragma: no cover
-        # kotti < 0.8
-        from kotti.static import edit_needed
-        edit_needed.add(kotti_tinymce)
+
+    resource_mapping['tinymce'] = [
+        tinymce, kotti_tinymce, kottiimage_plugin, codemirror_plugin]
